﻿
CREATE DATABASE [RZ_DICOM]

GO

USE [RZ_DICOM]

GO

SET ANSI_NULLS ON

GO

SET QUOTED_IDENTIFIER ON

GO



CREATE TABLE [dbo].[STORAGE_COMMIT_REQUEST](
	[scm_id] [int] IDENTITY(1,1) NOT NULL,
	[creation_time] [datetime] NOT NULL CONSTRAINT [DF_STORGAE_COMMIT_REQUEST_creation_time]  DEFAULT (getdate()),
	[update_time] [datetime] NULL,
	[scm_source_ae] [nvarchar](64) NOT NULL,
	[scm_transaction_uid] [nvarchar](64) NOT NULL,
	[tasks_queued] [int] NULL,
	[response_retry_count] [int] NOT NULL CONSTRAINT [DF_STORAGE_COMMIT_REQUEST_retry_count]  DEFAULT ((0)),
	[response_status] [int] NULL,
	[scm_kind] [int] NOT NULL CONSTRAINT [DF_STORAGE_COMMIT_REQUEST_scm_kind]  DEFAULT ((0)),
	[task_id] [int] NULL,
 CONSTRAINT [PK_STORGAE_COMMIT_REQUEST] PRIMARY KEY CLUSTERED 
(
	[scm_id] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY],
 CONSTRAINT [IX_STORGAE_COMMIT_REQUEST] UNIQUE NONCLUSTERED 
(
	[scm_transaction_uid] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]

GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'The number of tasks that were created following the incomming commit request' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'STORAGE_COMMIT_REQUEST', @level2type=N'COLUMN',@level2name=N'tasks_queued'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'The task that generated this outgoing commit request' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'STORAGE_COMMIT_REQUEST', @level2type=N'COLUMN',@level2name=N'task_id'
GO

SET ANSI_NULLS ON

GO

SET QUOTED_IDENTIFIER ON

GO

CREATE TABLE [dbo].[CONFIGURATION](
	[Key] [nvarchar](50) NOT NULL,
	[Value] [nvarchar](50) NOT NULL,
	[Description] [nvarchar](max) NULL,
 CONSTRAINT [PK_CONFIGURATION] PRIMARY KEY CLUSTERED 
(
	[Key] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]

GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'A unique key of the configuration elemet' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'CONFIGURATION', @level2type=N'COLUMN',@level2name=N'Key'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'The value of this entry' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'CONFIGURATION', @level2type=N'COLUMN',@level2name=N'Value'
GO
EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'A short description of the key and the value and their use' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'CONFIGURATION', @level2type=N'COLUMN',@level2name=N'Description'
GO

SET ANSI_NULLS ON

GO

SET QUOTED_IDENTIFIER ON

GO

CREATE TABLE [dbo].[DICOM_APPLICATIONS](

	[id] [int] IDENTITY(1,1) NOT NULL,

	[alias] [nvarchar](max) NULL,

	[ae_title] [nvarchar](64) NOT NULL,

	[host] [nvarchar](64) NULL,

	[port] [int] NULL,

 CONSTRAINT [PK_DICOM_APPLICATIONS] PRIMARY KEY CLUSTERED 

(

	[id] ASC

)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

) ON [PRIMARY]

GO

CREATE UNIQUE NONCLUSTERED INDEX [IX_DICOM_APPLICATIONS_AE_TITLE] ON [dbo].[DICOM_APPLICATIONS] 

(

	[ae_title] ASC

)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'The AE Title is unique' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'DICOM_APPLICATIONS', @level2type=N'INDEX',@level2name=N'IX_DICOM_APPLICATIONS_AE_TITLE'

GO

SET ANSI_NULLS ON

GO

SET QUOTED_IDENTIFIER ON

GO

CREATE TABLE [dbo].[STORAGE_COMMIT_REQUEST_INSTANCES](
	[scm_id] [int] NOT NULL,
	[sop_class_uid] [nvarchar](64) NOT NULL,
	[sop_instance_uid] [nvarchar](64) NOT NULL,
	[status] [int] NOT NULL CONSTRAINT [DF_STORAGE_COMMIT_REQUEST_INSTANCES_status]  DEFAULT ((2)),
	[failure_reason] [int] NOT NULL CONSTRAINT [DF_STORAGE_COMMIT_REQUEST_INSTANCES_failure_reason]  DEFAULT ((0)),
 CONSTRAINT [PK_STORAGE_COMMIT_REQUEST_INSTANCES] PRIMARY KEY CLUSTERED 
(
	[scm_id] ASC,
	[sop_class_uid] ASC,
	[sop_instance_uid] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO

CREATE NONCLUSTERED INDEX [IX_STORAGE_COMMIT_REQUEST_INSTANCES_1] ON [dbo].[STORAGE_COMMIT_REQUEST_INSTANCES] 
(
	[sop_class_uid] ASC,
	[sop_instance_uid] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
GO

SET ANSI_NULLS ON

GO

SET QUOTED_IDENTIFIER ON

GO

CREATE TABLE [dbo].[DICOM_FILES](
	[file_id] [int] IDENTITY(1,1) NOT NULL,
	[creation_time] [datetime] NOT NULL CONSTRAINT [DF_DICOM_FILES_creation_time]  DEFAULT (getdate()),
	[update_time] [datetime] NULL,
	[patient_name] [nvarchar](64) NOT NULL,
	[patient_id] [nvarchar](64) NOT NULL,
	[patient_sex] [nchar](1) NULL,
	[patient_birth_date] [datetime] NULL,
	[study_instance_uid] [nvarchar](64) NOT NULL,
	[study_id] [nvarchar](16) NULL,
	[study_date_time] [datetime] NULL,
	[accession_number] [nvarchar](16) NULL,
	[modality] [nvarchar](16) NULL,
	[series_number] [nvarchar](16) NULL,
	[series_instance_uid] [nvarchar](64) NOT NULL,
	[instance_number] [nvarchar](16) NULL,
	[sop_class_uid] [nvarchar](64) NOT NULL,
	[sop_instance_uid] [nvarchar](64) NOT NULL,
	[source_ae_title] [nvarchar](64) NULL,
	[rel_path] [nvarchar](max) NOT NULL,
	[task_id] [int] NULL,
 CONSTRAINT [PK_DICOM_FILES] PRIMARY KEY CLUSTERED 

(

	[file_id] ASC

)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

) ON [PRIMARY]

GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'A unique identifier of the file' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'DICOM_FILES', @level2type=N'COLUMN',@level2name=N'file_id'

GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'A timestamp when the record was created' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'DICOM_FILES', @level2type=N'COLUMN',@level2name=N'creation_time'

GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'A timestamp when the record was updated' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'DICOM_FILES', @level2type=N'COLUMN',@level2name=N'update_time'

GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Patient Name' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'DICOM_FILES', @level2type=N'COLUMN',@level2name=N'patient_name'

GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Patient ID' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'DICOM_FILES', @level2type=N'COLUMN',@level2name=N'patient_id'

GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Study Instance UID' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'DICOM_FILES', @level2type=N'COLUMN',@level2name=N'study_instance_uid'

GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Series Instance UID' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'DICOM_FILES', @level2type=N'COLUMN',@level2name=N'series_instance_uid'

GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'SOP Class UID' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'DICOM_FILES', @level2type=N'COLUMN',@level2name=N'sop_class_uid'

GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'SOP Instance UID' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'DICOM_FILES', @level2type=N'COLUMN',@level2name=N'sop_instance_uid'

GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'The AE Title that stored the file' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'DICOM_FILES', @level2type=N'COLUMN',@level2name=N'source_ae_title'

GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Relative path' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'DICOM_FILES', @level2type=N'COLUMN',@level2name=N'rel_path'

GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'The task id that process the file' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'DICOM_FILES', @level2type=N'COLUMN',@level2name=N'task_id'

GO

EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'The DICOM_FILES table holds one record for every DICOM File stored in the system.' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'DICOM_FILES'

GO


CREATE UNIQUE NONCLUSTERED INDEX [IX_DICOM_FILES_1] ON [dbo].[DICOM_FILES] 

(

	[patient_name] ASC,

	[patient_id] ASC,

	[study_instance_uid] ASC,

	[series_instance_uid] ASC,

	[sop_class_uid] ASC,

	[sop_instance_uid] ASC,

	[task_id] ASC

)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO


CREATE NONCLUSTERED INDEX [IX_DICOM_FILES_2] ON [dbo].[DICOM_FILES] 

(

	[sop_class_uid] ASC,

	[sop_instance_uid] ASC

)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]

GO



SET ANSI_NULLS ON

GO

SET QUOTED_IDENTIFIER ON

GO

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE VIEW [dbo].[UNFINISHED_STORAGE_COMMIT_REQUESTS]
AS
SELECT     dbo.STORAGE_COMMIT_REQUEST.scm_id, dbo.STORAGE_COMMIT_REQUEST.scm_source_ae, dbo.DICOM_APPLICATIONS.host, 
                      dbo.DICOM_APPLICATIONS.port, dbo.STORAGE_COMMIT_REQUEST.scm_transaction_uid
FROM         dbo.STORAGE_COMMIT_REQUEST INNER JOIN
                      dbo.DICOM_APPLICATIONS ON dbo.STORAGE_COMMIT_REQUEST.scm_source_ae = dbo.DICOM_APPLICATIONS.ae_title
WHERE     (dbo.STORAGE_COMMIT_REQUEST.response_status IS NULL OR
                      dbo.STORAGE_COMMIT_REQUEST.response_status <> 0) AND (dbo.STORAGE_COMMIT_REQUEST.response_retry_count <
                          (SELECT     CAST(Value AS int) AS Expr1
                            FROM          dbo.CONFIGURATION AS CONFIGURATION_1
                            WHERE      ([Key] = 'scm_max_retry'))) AND (dbo.STORAGE_COMMIT_REQUEST.update_time < -
                          ((SELECT     CAST(Value AS float) AS Expr1
                              FROM         dbo.CONFIGURATION
                              WHERE     ([Key] = 'retry_seconds')) / 60 / 60 / 24) + GETDATE()) AND (dbo.STORAGE_COMMIT_REQUEST.scm_kind = 1) OR
                      (dbo.STORAGE_COMMIT_REQUEST.response_status IS NULL OR
                      dbo.STORAGE_COMMIT_REQUEST.response_status <> 0) AND (dbo.STORAGE_COMMIT_REQUEST.response_retry_count = 0) AND 
                      (dbo.STORAGE_COMMIT_REQUEST.scm_kind = 1)

GO

SET ANSI_NULLS ON

GO

SET QUOTED_IDENTIFIER ON

GO

CREATE VIEW [dbo].[STORAGE_COMMIT_SUCCEEDED_INSTANCES]

AS

SELECT     dbo.STORAGE_COMMIT_REQUEST_INSTANCES.scm_id, dbo.STORAGE_COMMIT_REQUEST_INSTANCES.sop_class_uid, 

                      dbo.STORAGE_COMMIT_REQUEST_INSTANCES.sop_instance_uid

FROM         dbo.STORAGE_COMMIT_REQUEST_INSTANCES INNER JOIN

                      dbo.DICOM_FILES ON dbo.STORAGE_COMMIT_REQUEST_INSTANCES.sop_class_uid = dbo.DICOM_FILES.sop_class_uid AND 

                      dbo.STORAGE_COMMIT_REQUEST_INSTANCES.sop_instance_uid = dbo.DICOM_FILES.sop_instance_uid

GO

/****** Object:  View [dbo].[CFIND_IMAGE_VIEW]    Script Date: 11/20/2008 16:19:00 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE VIEW [dbo].[CFIND_IMAGE_VIEW]
AS
SELECT DISTINCT 
                patient_name AS PatientsName, patient_id AS PatientID, 
				study_id AS StudyID, study_date_time AS StudyDate,
				accession_number AS AccessionNumber,
				study_instance_uid AS StudyInstanceUID, modality AS Modality,
				series_number AS SeriesNumber,
				series_instance_uid AS SeriesInstanceUID, 
				instance_number AS InstanceNumber,
                sop_class_uid AS SOPClassUID, sop_instance_uid AS SOPInstanceUID
FROM         dbo.DICOM_FILES

GO

/****** Object:  View [dbo].[CFIND_SERIES_VIEW]    Script Date: 11/20/2008 16:18:26 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE VIEW [dbo].[CFIND_SERIES_VIEW]
AS
SELECT DISTINCT 
                      patient_name AS PatientsName, patient_id AS PatientID, 
				study_id AS StudyID, study_date_time AS StudyDate,
				accession_number AS AccessionNumber,
				study_instance_uid AS StudyInstanceUID, modality AS Modality,
				series_number AS SeriesNumber,
				series_instance_uid AS SeriesInstanceUID
FROM         dbo.DICOM_FILES

GO

/****** Object:  View [dbo].[CFIND_STUDY_VIEW]    Script Date: 11/20/2008 16:17:31 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE VIEW [dbo].[CFIND_STUDY_VIEW]
AS
SELECT DISTINCT 
	patient_name AS PatientName, 
	patient_id AS PatientID, 
	study_id AS StudyID,
	study_date_time AS StudyDate, 
	accession_number AS AccessionNumber, 
	study_instance_uid AS StudyInstanceUID, 
	patient_sex AS PatientSex, 
	patient_birth_date AS PatientBirthDate
FROM         dbo.DICOM_FILES
GO

/****** Object:  View [dbo].[CFIND_PATIENT_VIEW]    Script Date: 11/20/2008 16:12:53 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE VIEW [dbo].[CFIND_PATIENT_VIEW]
AS
SELECT DISTINCT 
    patient_name AS PatientName, 
	patient_id AS PatientID, 
	patient_sex AS PatientSex, 
	patient_birth_date AS PatientBirthDate
FROM         dbo.DICOM_FILES
GO

/****** Object:  View [dbo].[CMOVE_PATIENT_VIEW]    Script Date: 11/20/2008 16:23:29 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE VIEW [dbo].[CMOVE_PATIENT_VIEW]
AS
SELECT DISTINCT 
                      dbo.DICOM_FILES.patient_name AS PatientsName, dbo.DICOM_FILES.patient_id AS PatientID, 
                      dbo.CONFIGURATION.Value + '\' + dbo.DICOM_FILES.rel_path AS file_path
FROM         dbo.DICOM_FILES CROSS JOIN
                      dbo.CONFIGURATION
WHERE     (dbo.CONFIGURATION.[Key] = 'root_dir')

GO

/****** Object:  View [dbo].[CMOVE_STUDY_VIEW]    Script Date: 11/20/2008 16:23:48 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE VIEW [dbo].[CMOVE_STUDY_VIEW]
AS
SELECT DISTINCT 
                patient_name AS PatientsName, patient_id AS PatientID, 
				study_id AS StudyID, study_date_time AS StudyDate,
				accession_number AS AccessionNumber,
				study_instance_uid AS StudyInstanceUID, dbo.CONFIGURATION.Value + '\' + dbo.DICOM_FILES.rel_path AS file_path
FROM         dbo.DICOM_FILES CROSS JOIN
                      dbo.CONFIGURATION
WHERE     (dbo.CONFIGURATION.[Key] = 'root_dir')

GO

/****** Object:  View [dbo].[CMOVE_SERIES_VIEW]    Script Date: 11/20/2008 16:30:18 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE VIEW [dbo].[CMOVE_SERIES_VIEW]
AS
SELECT DISTINCT 
                      patient_name AS PatientsName, patient_id AS PatientID, 
				study_id AS StudyID, study_date_time AS StudyDate,
				accession_number AS AccessionNumber,
				study_instance_uid AS StudyInstanceUID, modality AS Modality,
				series_number AS SeriesNumber,
				series_instance_uid AS SeriesInstanceUID, 
                      dbo.CONFIGURATION.Value + '\' + dbo.DICOM_FILES.rel_path AS file_path
FROM         dbo.DICOM_FILES CROSS JOIN
                      dbo.CONFIGURATION
WHERE     (dbo.CONFIGURATION.[Key] = 'root_dir')

GO

/****** Object:  View [dbo].[CMOVE_IMAGE_VIEW]    Script Date: 11/20/2008 16:30:44 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE VIEW [dbo].[CMOVE_IMAGE_VIEW]
AS
SELECT DISTINCT 
                      patient_name AS PatientsName, patient_id AS PatientID, 
				study_id AS StudyID, study_date_time AS StudyDate,
				accession_number AS AccessionNumber,
				study_instance_uid AS StudyInstanceUID, modality AS Modality,
				series_number AS SeriesNumber,
				series_instance_uid AS SeriesInstanceUID, 
				instance_number AS InstanceNumber,
                sop_class_uid AS SOPClassUID, sop_instance_uid AS SOPInstanceUID, 
                      dbo.CONFIGURATION.Value + '\' + dbo.DICOM_FILES.rel_path AS file_path
FROM         dbo.DICOM_FILES CROSS JOIN
                      dbo.CONFIGURATION
WHERE     (dbo.CONFIGURATION.[Key] = 'root_dir')

GO

SET ANSI_NULLS ON

GO

SET QUOTED_IDENTIFIER ON

GO

CREATE VIEW [dbo].[STORAGE_COMMIT_FAILED_INSTANCES]

AS

SELECT     dbo.STORAGE_COMMIT_REQUEST_INSTANCES.scm_id, dbo.STORAGE_COMMIT_REQUEST_INSTANCES.sop_class_uid, 

                      dbo.STORAGE_COMMIT_REQUEST_INSTANCES.sop_instance_uid

FROM         dbo.STORAGE_COMMIT_REQUEST_INSTANCES LEFT OUTER JOIN

                      dbo.DICOM_FILES ON dbo.STORAGE_COMMIT_REQUEST_INSTANCES.sop_class_uid = dbo.DICOM_FILES.sop_class_uid AND 

                      dbo.STORAGE_COMMIT_REQUEST_INSTANCES.sop_instance_uid = dbo.DICOM_FILES.sop_instance_uid

WHERE     (dbo.DICOM_FILES.file_id IS NULL)

GO

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO


SET ANSI_NULLS ON

GO

SET QUOTED_IDENTIFIER ON

GO

CREATE PROCEDURE [dbo].[SetLocalAE]

	-- Add the parameters for the stored procedure here

	@ae_title nvarchar(16), 

	@port int

AS

BEGIN

	SET NOCOUNT ON;

	update CONFIGURATION set [Value] = @ae_title WHERE ([Key] = 'ae_title')

	update CONFIGURATION set [Value] = @port WHERE ([Key] = 'port')

END

GO

SET ANSI_NULLS ON

GO

SET QUOTED_IDENTIFIER ON

GO


SET ANSI_NULLS ON

GO

SET QUOTED_IDENTIFIER ON

GO

CREATE PROCEDURE [dbo].[SetVerbose]

(

	@param1 nvarchar(50)

)

AS

	SET NOCOUNT OFF;

UPDATE    CONFIGURATION

SET              Value = @param1

WHERE     ([Key] = 'Verbose')

GO

SET ANSI_NULLS ON

GO

SET QUOTED_IDENTIFIER ON

GO

CREATE PROCEDURE [dbo].[SetDicomLog]

(

	@param1 nvarchar(50)

)

AS

	SET NOCOUNT OFF;

UPDATE    CONFIGURATION

SET              Value = @param1

WHERE     ([Key] = 'dicom_log')

GO

SET ANSI_NULLS ON

GO

SET QUOTED_IDENTIFIER ON

GO

CREATE PROCEDURE [dbo].[GetLocalAE]  @ae_title nvarchar(16) output,  @port int output

AS

SET NOCOUNT ON;

SELECT @ae_title = [Value] FROM CONFIGURATION WHERE ([Key] = 'ae_title')

SELECT @port = [Value] FROM CONFIGURATION WHERE ([Key] = 'port')

GO

SET ANSI_NULLS ON

GO

SET QUOTED_IDENTIFIER ON

GO

-- =============================================

-- Author:		Arie Vainstein

-- Create date: 18/9/2008

-- Description:	Get the first image in the study

-- =============================================

CREATE PROCEDURE [dbo].[GetFirstImage]
AS

BEGIN
	
	-- SET NOCOUNT ON added to prevent extra result sets from

	-- interfering with SELECT statements.

	SET NOCOUNT ON;

	SELECT 
		Top 1 [DICOM_FILES].[rel_path]
	FROM [DICOM_FILES]
	GROUP BY 
		[DICOM_FILES].[rel_path]
	
END

GO

SET ANSI_NULLS ON

GO

SET QUOTED_IDENTIFIER ON

GO

-- =============================================

-- Author:		Arie Vainstein

-- Create date: 18/9/2008

-- Description:	GetFirstImageInSeriesPath

-- =============================================

CREATE PROCEDURE [dbo].[GetFirstImageInSeriesPath]
	@SeriesUID nvarchar(MAX)
AS

BEGIN
	
	-- SET NOCOUNT ON added to prevent extra result sets from

	-- interfering with SELECT statements.

	SET NOCOUNT ON;

	SELECT 
		Top 1 [DICOM_FILES].[rel_path]
	FROM [DICOM_FILES]
	WHERE
		([DICOM_FILES].[series_instance_uid] = @SeriesUID)
	GROUP BY 
		[DICOM_FILES].[rel_path]

END

GO

SET ANSI_NULLS ON

GO

SET QUOTED_IDENTIFIER ON

GO


-- =============================================

-- Author:		Arie Vainstein

-- Create date: 18/9/2008

-- Description:	GetFirstStudy

-- =============================================

CREATE PROCEDURE [dbo].[GetFirstStudy]
AS

BEGIN
	
	-- SET NOCOUNT ON added to prevent extra result sets from

	-- interfering with SELECT statements.

	SET NOCOUNT ON;

	SELECT 
		TOP 1 [DICOM_FILES].[study_instance_uid]
	FROM [DICOM_FILES]
	GROUP BY 
		[DICOM_FILES].[study_instance_uid]
	
END

GO

SET ANSI_NULLS ON

GO

SET QUOTED_IDENTIFIER ON

GO

-- =============================================

-- Author:		Arie Vainstein

-- Create date: 18/9/2008

-- Description:	GetImagePaths

-- =============================================

CREATE PROCEDURE [dbo].[GetImagePaths]
	@SeriesUID nvarchar(MAX)
AS

BEGIN
	
	-- SET NOCOUNT ON added to prevent extra result sets from

	-- interfering with SELECT statements.

	SET NOCOUNT ON;

	SELECT 
		[DICOM_FILES].[rel_path]
	FROM [DICOM_FILES]
	WHERE
		([DICOM_FILES].[series_instance_uid] = @SeriesUID)
	GROUP BY 
		[DICOM_FILES].[rel_path]

END

GO

/****** Object:  StoredProcedure [dbo].[GetRootDir]    Script Date: 09/22/2008 15:49:38 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [dbo].[GetRootDir]

AS

SET NOCOUNT ON;

SELECT [Value] FROM CONFIGURATION WHERE ([Key] = 'root_dir')

GO

SET ANSI_NULLS ON

GO

SET QUOTED_IDENTIFIER ON

GO

-- =============================================

-- Author:		Arie Vainstein

-- Create date: 18/9/2008

-- Description:	GetSeries

-- =============================================

CREATE PROCEDURE [dbo].[GetSeries]
	@StudyUID nvarchar(MAX)
AS

BEGIN
	
	-- SET NOCOUNT ON added to prevent extra result sets from

	-- interfering with SELECT statements.

	SET NOCOUNT ON;

	SELECT 
		[DICOM_FILES].[series_instance_uid], [DICOM_FILES].[study_instance_uid]
	FROM [DICOM_FILES]
	WHERE
		([DICOM_FILES].[study_instance_uid] = @StudyUID)
	GROUP BY 
		[DICOM_FILES].[series_instance_uid], [DICOM_FILES].[study_instance_uid]
	
END

GO

SET ANSI_NULLS ON

GO

SET QUOTED_IDENTIFIER ON

GO

-- =============================================

-- Author:		Arie Vainstein

-- Create date: 18/9/2008

-- Description:	GetStudies

-- =============================================

CREATE PROCEDURE [dbo].[GetStudies]
	@PatientID nvarchar(MAX),
	@PatientName nvarchar(MAX)
AS

BEGIN
	
	-- SET NOCOUNT ON added to prevent extra result sets from

	-- interfering with SELECT statements.

	SET NOCOUNT ON;

	SELECT 
		[DICOM_FILES].[study_instance_uid], 
		Count(*) AS NumberOfSeries 
	FROM [DICOM_FILES]
	WHERE
		([DICOM_FILES].[patient_id] like @PatientID AND [DICOM_FILES].[patient_name] like @PatientName)
	GROUP BY 
		[DICOM_FILES].[study_instance_uid]
	
END

GO

/****** Object:  StoredProcedure [dbo].[GetWebVirtualDir]    Script Date: 09/22/2008 15:52:32 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [dbo].[GetWebVirtualDir]

AS

SET NOCOUNT ON;

SELECT [Value] FROM CONFIGURATION WHERE ([Key] = 'web_virtual_dir')

GO

-- =============================================

-- Author:		Arie Vainstein

-- Create date: 22/9/2008

-- Description:	GetWebDir

-- =============================================

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [dbo].[GetWebDir]

AS

SET NOCOUNT ON;

SELECT [Value] FROM CONFIGURATION WHERE ([Key] = 'web_dir')

GO


-- =============================================

-- Author:		Arie

-- Create date: 7/7/2008

-- Description:	SCM Cleanup

-- =============================================

CREATE PROCEDURE [dbo].[CleanOldSCMs] 
AS
BEGIN
	SET NOCOUNT ON;
	declare @cleantime datetime
	select @cleantime = (GETDATE() - (SELECT     CAST(Value AS float) AS Expr1
                            FROM          dbo.CONFIGURATION
                            WHERE      ([Key] = 'cleanup_seconds')) / 60 / 60 / 24)
	delete from storage_commit_request
	where (creation_time < @cleantime AND update_time < @cleantime) OR
		  (creation_time < @cleantime AND (update_time IS NULL))
END
GO



ALTER TABLE [dbo].[STORAGE_COMMIT_REQUEST_INSTANCES]  WITH CHECK ADD  CONSTRAINT [FK_STORAGE_COMMIT_REQUEST_INSTANCES_STORGAE_COMMIT_REQUEST] FOREIGN KEY([scm_id])
REFERENCES [dbo].[STORAGE_COMMIT_REQUEST] ([scm_id])
ON DELETE CASCADE
GO
ALTER TABLE [dbo].[STORAGE_COMMIT_REQUEST_INSTANCES] CHECK CONSTRAINT [FK_STORAGE_COMMIT_REQUEST_INSTANCES_STORGAE_COMMIT_REQUEST]
GO

-- =============================================
-- Author:		Roni
-- Create date	14/5/2012
-- Description	MWL tables and views
-- =============================================

/****** Object:  Table [dbo].[N_PATIENT]    Script Date: 05/14/2012 16:50:50 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[N_PATIENT](
	[id] [int] IDENTITY(1,1) NOT NULL,
	[patient_id] [nvarchar](64) NULL,
	[patient_name] [nvarchar](64) NULL,
	[birth_date] [datetime] NULL,
	[sex] [nchar](1) NULL,
 CONSTRAINT [PK_N_PATIENT] PRIMARY KEY CLUSTERED 
(
	[id] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
/****** Object:  Table [dbo].[SERVICE_REQUEST]    Script Date: 05/14/2012 16:50:56 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[SERVICE_REQUEST](
	[id] [int] IDENTITY(1,1) NOT NULL,
	[accession_number] [nvarchar](50) NULL,
	[referring_physicians_names] [nvarchar](400) NULL,
	[requesting_physician] [nvarchar](400) NULL,
 CONSTRAINT [PK_SERVICE_REQUEST] PRIMARY KEY CLUSTERED 
(
	[id] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[REQUESTED_PROCEDURE]    Script Date: 12/15/2012 08:15:45 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[REQUESTED_PROCEDURE](
	[id] [int] IDENTITY(1,1) NOT NULL,
	[study_instance_uid] [nvarchar](64) NULL,
	[req_proc_desc] [nvarchar](64) NULL,
	[req_proc_id] [nvarchar](50) NULL,
	[service_request_id] [int] NULL,
	[patient_internal_id] [int] NULL,
	[RequestedProcedureCodeSequence] [int] NULL,
 CONSTRAINT [PK_REQUESTED_PROCEDURE] PRIMARY KEY CLUSTERED 
(
	[id] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[SCHED_PROC_STEP]    Script Date: 05/14/2012 16:50:55 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[SCHED_PROC_STEP](
	[id] [int] IDENTITY(1,1) NOT NULL,
	[modality] [nvarchar](16) NULL,
	[scheduled_station_ae_title] [nvarchar](16) NULL,
	[start_date_time] [datetime] NULL,
	[end_date_time] [datetime] NULL,
	[perf_phys_name] [nvarchar](250) NULL,
	[sched_proc_step_desc] [nvarchar](64) NULL,
	[sched_proc_step_id] [nvarchar](16) NULL,
	[req_proc_id] [int] NOT NULL,
 CONSTRAINT [PK_SCHED_PROC_STEP] PRIMARY KEY CLUSTERED 
(
	[id] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[DICOM_CODES]    Script Date: 12/15/2012 08:18:33 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[DICOM_CODES](
	[id] [int] IDENTITY(1,1) NOT NULL,
	[CodeValue] [nvarchar](50) NULL,
	[CodingSchemeDesignator] [nvarchar](50) NULL,
	[CodingSchemeVersion] [nvarchar](50) NULL,
	[CodeMeaning] [nvarchar](50) NULL,
 CONSTRAINT [PK_DICOM_CODES] PRIMARY KEY CLUSTERED 
(
	[id] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY]
GO

/****** Object:  View [dbo].[CFIND_MWL_VIEW]    Script Date: 05/14/2012 16:50:56 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE VIEW [dbo].[CFIND_MWL_VIEW]
AS
SELECT        dbo.REQUESTED_PROCEDURE.study_instance_uid AS StudyInstanceUID, 
                         dbo.REQUESTED_PROCEDURE.req_proc_desc AS RequestedProcedureDescription, 
                         dbo.REQUESTED_PROCEDURE.id AS ScheduledProcedureStepSequence, dbo.REQUESTED_PROCEDURE.req_proc_id AS RequestedProcedureID, 
                         dbo.SERVICE_REQUEST.accession_number AS AccessionNumber, dbo.SERVICE_REQUEST.referring_physicians_names AS ReferringPhysicianName, 
                         dbo.SERVICE_REQUEST.requesting_physician AS RequestingPhysician, dbo.N_PATIENT.patient_id AS PatientID, 
                         dbo.N_PATIENT.patient_name AS PatientName, CONVERT(char(8), dbo.N_PATIENT.birth_date, 112) AS PatientBirthDate, 
                         dbo.N_PATIENT.sex AS PatientSex, 
                         NULL AS PatientWeight, 
                         NULL AS MedicalAlerts, NULL AS Allergies, 
                         NULL AS PregnancyStatus, 
                         NULL AS RequestedContrastAgent, 
                         NULL AS AdmissionID, 
                         NULL AS SpecialNeeds, 
                         NULL AS CurrentPatientLocation, 
                         NULL AS PatientState, 
                         NULL AS RequestedProcedurePriority, 
                         NULL AS PatientTransportArrangements, 
                         NULL AS ConfidentialityConstraintOnPatientDataDescription
FROM            dbo.REQUESTED_PROCEDURE INNER JOIN
                         dbo.SERVICE_REQUEST ON dbo.REQUESTED_PROCEDURE.service_request_id = dbo.SERVICE_REQUEST.id INNER JOIN
                         dbo.N_PATIENT ON dbo.REQUESTED_PROCEDURE.patient_internal_id = dbo.N_PATIENT.id
GO

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE VIEW [dbo].[CFIND_ScheduledProcedureStepSequence_VIEW]
AS
SELECT        
	id, 
	modality, 
	scheduled_station_ae_title AS ScheduledStationAETitle, 
	CONVERT(char(8), start_date_time, 112) AS ScheduledProcedureStepStartDate, 
    perf_phys_name AS ScheduledPerformingPhysicianName, 
    req_proc_id AS ScheduledProcedureStepSequence, 
    REPLACE(CONVERT(char(8), start_date_time, 108), ':', '') AS ScheduledProcedureStepStartTime, 
    sched_proc_step_desc AS ScheduledProcedureStepDescription, 
    'SPSID' + CAST(id AS nvarchar) AS ScheduledProcedureStepID, 
    NULL AS ScheduledPerformingPhysiciansName, 
    NULL AS ScheduledStationName, 
    NULL AS ScheduledProcedureStepLocation, 
    NULL AS PreMedication
FROM            
	dbo.SCHED_PROC_STEP
GO

ALTER TABLE [dbo].[REQUESTED_PROCEDURE]  WITH CHECK ADD  CONSTRAINT [FK_REQUESTED_PROCEDURE_DICOM_CODES] FOREIGN KEY([RequestedProcedureCodeSequence])
REFERENCES [dbo].[DICOM_CODES] ([id])
GO
ALTER TABLE [dbo].[REQUESTED_PROCEDURE] CHECK CONSTRAINT [FK_REQUESTED_PROCEDURE_DICOM_CODES]
GO
ALTER TABLE [dbo].[REQUESTED_PROCEDURE]  WITH CHECK ADD  CONSTRAINT [FK_REQUESTED_PROCEDURE_N_PATIENT] FOREIGN KEY([patient_internal_id])
REFERENCES [dbo].[N_PATIENT] ([id])
GO
ALTER TABLE [dbo].[REQUESTED_PROCEDURE] CHECK CONSTRAINT [FK_REQUESTED_PROCEDURE_N_PATIENT]
GO
ALTER TABLE [dbo].[REQUESTED_PROCEDURE]  WITH CHECK ADD  CONSTRAINT [FK_REQUESTED_PROCEDURE_SERVICE_REQUEST] FOREIGN KEY([service_request_id])
REFERENCES [dbo].[SERVICE_REQUEST] ([id])
GO
ALTER TABLE [dbo].[REQUESTED_PROCEDURE] CHECK CONSTRAINT [FK_REQUESTED_PROCEDURE_SERVICE_REQUEST]
GO
ALTER TABLE [dbo].[SCHED_PROC_STEP]  WITH CHECK ADD  CONSTRAINT [FK_SCHED_PROC_STEP_REQUESTED_PROCEDURE] FOREIGN KEY([req_proc_id])
REFERENCES [dbo].[REQUESTED_PROCEDURE] ([id])
GO
ALTER TABLE [dbo].[SCHED_PROC_STEP] CHECK CONSTRAINT [FK_SCHED_PROC_STEP_REQUESTED_PROCEDURE]
GO
